<?php
/**
*
* @link              https://wphotline.com
* @since             1.0
* @package           evergreens
*
* @evergreens
 * Plugin Name: Evergreens - your best content
 * Description: Highlight specific posts right in the admin and mark your best content
 * Version: 1.0
 * Author: Stefan Böttcher
 * Domain Path:       /languages
 */


//add admin columns
add_filter( 'manage_edit-post_columns', 'evergreencontent_add_admin_cloumns',15 );
function evergreencontent_add_admin_cloumns($columns){

	$columns['is_evergreen'] = __('Evergreen','evergreens');
	return $columns;

}


//show admin column values
add_action( 'manage_posts_custom_column', 'evergreencontent_show_admin_cloumns', 10, 2 );
function evergreencontent_show_admin_cloumns( $column, $postid ) {

  if ( $column == 'is_evergreen' ) {
		$is_evergreen = get_post_meta( $postid, '_is_evergreen', true );
		if( !$is_evergreen ) { echo '<span class="evergreen-star dashicons dashicons-star-empty" data-postid="'.$postid.'"></span>'; } else { echo '<span class="evergreen-star dashicons dashicons-star-filled" data-postid="'.$postid.'"></span>'; }
  }

}

add_filter( 'manage_edit-post_sortable_columns', 'evergreencontent_sortable_column' );
function evergreencontent_sortable_column( $columns ) {
    $columns['is_evergreen'] = 'is_evergreen';
    return $columns;
}

add_action( 'pre_get_posts', 'is_evergreen_orderby' );
function is_evergreen_orderby( $query ) {
    if( ! is_admin() )
        return;

    $orderby = $query->get( 'orderby');

    if( 'is_evergreen' == $orderby ) {
        $query->set('meta_key','_is_evergreen');
        $query->set('orderby','meta_value');
    }
}


add_action( 'admin_head', 'evergreen_admin_scripts' ); // Write our JS below here

function evergreen_admin_scripts() {
	 if(current_user_can('edit_others_pages')) {
	?>
	<script type="text/javascript" >
	jQuery(document).ready(function($) {


		$('.evergreen-star').on('click', function() {

			var $that = $(this);
			var data = {
				'action': 'evergreen_admin_ajax_action',
				'post_id': $that.data('postid')
			};

			// since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
			jQuery.post(ajaxurl, data, function(response) {
				$that.toggleClass('evergreen-marked');
			});

		});

	});
	</script>

	<style>
	.column-is_evergreen { text-align: center; }
	.dashicons-star-filled.evergreen-star { color: orange; }
	.evergreen-star:hover { color: orange; cursor: pointer; }
	.dashicons-star-empty.evergreen-marked:before { content: "\f155"; }
	.dashicons-star-filled.evergreen-marked:before { content: "\f154"; }
	.misc-pub-post-evergreen .evergreen-star { backround: red; }
	</style>
	 <?php
	 }
}

add_action( 'wp_ajax_evergreen_admin_ajax_action', 'evergreen_admin_ajax_action' );

function evergreen_admin_ajax_action() {
	global $wpdb; // this is how you get access to the database

	$post_id = intval( $_POST['post_id'] );
	$return = 'nope';
	if($post_id && current_user_can('edit_others_pages') ) {
		$is_evergreen = get_post_meta( $post_id, '_is_evergreen', true );
		if( !$is_evergreen ) { $return = update_post_meta( $post_id, '_is_evergreen', 'true' ); } else { $return = delete_post_meta( $post_id, '_is_evergreen' );  }
	}

	echo $return;

	wp_die(); // this is required to terminate immediately and return a proper response
}

add_action( 'post_submitbox_misc_actions', 'evergreen_add_button_html' );
function evergreen_add_button_html(){


  global $post;

	$is_evergreen = get_post_meta( $post->ID, '_is_evergreen', true );
	$class = "";
	if( current_user_can('edit_others_pages') ) { $class = "evergreen-star"; }
	$html = '<hr /><div class="misc-pub-section misc-pub-post-evergreen"> ';
	if( !$is_evergreen ) { $html .= '<span class="'.$class.' dashicons dashicons-star-empty" data-postid="'.$post->ID.'"></span>&nbsp;&nbsp;'.__('no Evergreen','evergreens').''; } else { $html .= '<span class="'.$class.' dashicons dashicons-star-filled" data-postid="'.$post->ID.'"></span>&nbsp;&nbsp;'.__('Evergreen','evergreens').''; }
	$html .= '</div>';
	echo $html;

}

function is_evergreen( $post_id = null ) {

	if( empty($post_id) ) $post_id = get_the_ID();
	$post_id = intval( $post_id );

	if($post_id) {
		$is_evergreen = (bool) get_post_meta( $post_id, '_is_evergreen', true );
		return $is_evergreen;
	}

	return false;
}

add_shortcode( 'evergreens', 'evergreen__shortcode' );
function evergreen__shortcode( $atts ){

	$atts = shortcode_atts(
		array(
			'title' => false,
			'cat' => false,
			'posts_per_page' => 10,
			'orderby' => 'rand',
		), $atts, 'evergreens' );

	$html = "";

	$args = array(
		'exclude' => get_the_ID(),
		'posts_per_page' => $atts["posts_per_page"],
		'orderby' => $atts["orderby"],
		'cat' => $atts["cat"],
		'meta_query' => array(
		    array(
		     'key' => '_is_evergreen',
		     'compare' => 'EXITS' // this should work...
		    ),
		)
	);
	$posts = get_posts( $args );
	//if(current_user_can('administrator')) { echo '<pre>'; var_dump( $args ); echo '</pre>'; }

	if(!empty( $posts )) {

	if(!empty( $atts["title"] )) $html .= '<h3>'.$atts["title"].'</h3>';
	$html .= '<ul>';

	foreach($posts as $evergreen) {
		$title = get_the_title( $evergreen->ID );
		$html .= '<li><a href="'. get_permalink( $evergreen->ID ) .'" title="'.esc_attr($title).'" class="asmb-track evergreen-content-link">';
		$html .= $title.'';
		$html .= '</a></li>';
	}

	$html .= '</ul>';
	}

	return $html;
}
